@@ -837,7 +837,7 @@ DicomFile::mFindElement(const DicomTag& tag, DicomElement& element,
 		return 1;
 	}
 
-	if ((element.tag > tag) || !input.good()){
+	if ((element.tag > tag) || !input.good() || element.tag == DicomTag(0,0)){
 		input.clear();
 		if (input == mInputFile) 
 			input.seekg(mBeginning);
@@ -912,10 +912,28 @@ DicomFile::FindInSequence(const string& seq, DicomElement& d,
 	mReadElementTag(item, ss);
 	ss.read(reinterpret_cast<char*> (&item.value_length), sizeof(item.value_length));
 
+	int counter = 0;
 	while (ss.good()) { 
+		++counter;
+		wxLogStatus(_T("%d"), counter);
 
 		if (item.value_length != UNDEFINED) {
-			ss.ignore(item.value_length);
+			istream::pos_type pos = ss.tellg();
+			istream::pos_type end_pos = pos + static_cast<std::streamoff>(item.value_length);
+			DicomElement e;
+			while (ss.good() && (pos < end_pos)) {
+				mReadNextElement(e, ss);
+				if (e.tag == d.tag) {
+					string str;
+					ss.seekg(- static_cast<std::streamoff>(e.value_length), 
+						std::ios::cur);
+
+					mReadValue(e, str, ss);
+					v.push_back(str);
+					found = 1;
+				}
+				pos = ss.tellg();
+			}
 		}
 
 		else {
